unit MainForm;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls;

type
  TMainDlg = class(TForm)
    Label1: TLabel;
    StrEdit: TEdit;
    BooleanBtn: TButton;
    CurrencyBtn: TButton;
    DateBtn: TButton;
    DateTimeBtn: TButton;
    TimeBtn: TButton;
    IntegerBtn: TButton;
    DoubleBtn: TButton;
    Label2: TLabel;
    ResultLabel: TLabel;
    UseTryCB: TCheckBox;
    ValTestBtn: TButton;
    Label3: TLabel;
    Label4: TLabel;
    TrueMemo: TMemo;
    FalseMemo: TMemo;
    UpdateBoolStrsBtn: TButton;
    procedure BooleanBtnClick(Sender: TObject);
    procedure CurrencyBtnClick(Sender: TObject);
    procedure DateBtnClick(Sender: TObject);
    procedure DateTimeBtnClick(Sender: TObject);
    procedure TimeBtnClick(Sender: TObject);
    procedure IntegerBtnClick(Sender: TObject);
    procedure DoubleBtnClick(Sender: TObject);
    procedure ValTestBtnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure UpdateBoolStrsBtnClick(Sender: TObject);
  private
    procedure UpdateBoolStrMemos;
  public
  end;

var
  MainDlg: TMainDlg;


implementation

{$R *.dfm}

procedure TMainDlg.UpdateBoolStrMemos;
  var
    i : Integer;
begin
  TrueMemo.Clear;
  FalseMemo.Clear;
  
  for i := Low(TrueBoolStrs) to High(TrueBoolStrs) do begin
    TrueMemo.Lines.Add(TrueBoolStrs[i]);
  end;

  for i := Low(FalseBoolStrs) to High(FalseBoolStrs) do begin
    FalseMemo.Lines.Add(FalseBoolStrs[i]);
  end;
end;


procedure TMainDlg.FormCreate(Sender: TObject);
begin
  UpdateBoolStrMemos;
end;


procedure TMainDlg.BooleanBtnClick(Sender: TObject);
  var
    TempBool : Boolean;
begin
  if UseTryCB.Checked then begin
    if TryStrToBool(StrEdit.Text,TempBool) then begin
      ResultLabel.Caption := BoolToStr(TempBool);
    end else begin
      ResultLabel.Caption := StrEdit.Text + ' is not a valid boolean';
    end;
  end else begin
    ResultLabel.Caption := BoolToStr(StrToBool(StrEdit.Text));
  end;

  // TryStrToBool and BoolToStr will fill XXXXBoolStrs if necessary
  UpdateBoolStrMemos;
end;


procedure TMainDlg.UpdateBoolStrsBtnClick(Sender: TObject);
  var
    i : Integer;
begin
  SetLength(TrueBoolStrs,TrueMemo.Lines.Count);
  SetLength(FalseBoolStrs,FalseMemo.Lines.Count);

  for i := 0 to TrueMemo.Lines.Count - 1 do begin
   TrueBoolStrs[i] := TrueMemo.Lines[i];
  end;

  for i := 0 to FalseMemo.Lines.Count - 1 do begin
   FalseBoolStrs[i] := FalseMemo.Lines[i];
  end;
end;


procedure TMainDlg.CurrencyBtnClick(Sender: TObject);
  var
    TempCurr : Currency;
begin
  if UseTryCB.Checked then begin
    if TryStrToCurr(StrEdit.Text,TempCurr) then begin
      ResultLabel.Caption := CurrToStr(TempCurr);
    end else begin
      ResultLabel.Caption := StrEdit.Text + ' is not a valid currency';
    end;
  end else begin
    ResultLabel.Caption := CurrToStr(StrToCurr(StrEdit.Text));
  end;
end;


procedure TMainDlg.DateBtnClick(Sender: TObject);
  var
    TempDate       : TDateTime;
    FormatSettings : TFormatSettings;
begin
  GetLocaleFormatSettings(LOCALE_USER_DEFAULT,FormatSettings);
  FormatSettings.DateSeparator := '-';

  if UseTryCB.Checked then begin
    if TryStrToDate(StrEdit.Text,TempDate,FormatSettings) then begin
      ResultLabel.Caption := DateToStr(TempDate);
    end else begin
      ResultLabel.Caption := StrEdit.Text + ' is not a valid date';
    end;
  end else begin
    ResultLabel.Caption := DateToStr(StrToDate(StrEdit.Text,FormatSettings));
  end;
end;


procedure TMainDlg.DateTimeBtnClick(Sender: TObject);
  var
    TempDate : TDateTime;
begin
  if UseTryCB.Checked then begin
    if TryStrToDateTime(StrEdit.Text,TempDate) then begin
      ResultLabel.Caption := DateTimeToStr(TempDate);
    end else begin
      ResultLabel.Caption := StrEdit.Text + ' is not a valid datetime';
    end;
  end else begin
    ResultLabel.Caption := DateTimeToStr(StrToDateTime(StrEdit.Text));
  end;
end;


procedure TMainDlg.TimeBtnClick(Sender: TObject);
  var
    TempTime : TDateTime;
begin
  if UseTryCB.Checked then begin
    if TryStrToTime(StrEdit.Text,TempTime) then begin
      ResultLabel.Caption := TimeToStr(TempTime);
    end else begin
      ResultLabel.Caption := StrEdit.Text + ' is not a valid time';
    end;
  end else begin
    ResultLabel.Caption := TimeToStr(StrToTime(StrEdit.Text));
  end;
end;


procedure TMainDlg.IntegerBtnClick(Sender: TObject);
  var
    TempInt : Integer;
begin
  if UseTryCB.Checked then begin
    if TryStrToInt(StrEdit.Text,TempInt) then begin
      ResultLabel.Caption := IntToStr(TempInt);
    end else begin
      ResultLabel.Caption := StrEdit.Text + ' is not a valid integer';
    end;
  end else begin
    ResultLabel.Caption := IntToStr(StrToInt(StrEdit.Text));
  end;
end;


procedure TMainDlg.DoubleBtnClick(Sender: TObject);
  var
    TempDouble : Double;
begin
  if UseTryCB.Checked then begin
    if TryStrToFloat(StrEdit.Text,TempDouble) then begin
      ResultLabel.Caption := FloatToStr(TempDouble);
    end else begin
      ResultLabel.Caption := StrEdit.Text + ' is not a valid double';
    end;
  end else begin
    ResultLabel.Caption := FloatToStr(StrToFloat(StrEdit.Text));
  end;
end;


procedure TMainDlg.ValTestBtnClick(Sender: TObject);
  var
    TempInt  : Integer;
    ErrorPos : Integer;
begin
  Val(StrEdit.Text,TempInt,ErrorPos);

  if ErrorPos = 0 then begin
    ResultLabel.Caption := IntToStr(TempInt);
  end else begin
    ResultLabel.Caption := 'Bad character at position ' + IntToStr(ErrorPos);
  end;
end;


end.
